# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        HealthStatus,
        Product,
        ProductConfig,
        ProductConfigAddOn1Tb,
        ProductConfigAddOn1TbId,
        ProductConfigAddOn200Gb,
        ProductConfigAddOn200GbId,
        ProductConfigAddOn500Gb,
        ProductConfigAddOn500GbId,
        ProductConfigChatAgent,
        ProductConfigChatAgentId,
        ProductConfigChatintegrationProfessional,
        ProductConfigChatintegrationProfessionalId,
        ProductConfigChatintegrationStarter,
        ProductConfigChatintegrationStarterId,
        ProductConfigDeveloper,
        ProductConfigDeveloperId,
        ProductConfigProjectroom,
        ProductConfigProjectroomId,
        UploadResponse,
        VectorUpdateResponse,
    )
    from .client import AsyncConcreteApi, ConcreteApi
    from .environment import ConcreteApiEnvironment
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "AsyncConcreteApi": ".client",
    "ConcreteApi": ".client",
    "ConcreteApiEnvironment": ".environment",
    "HealthStatus": ".types",
    "Product": ".types",
    "ProductConfig": ".types",
    "ProductConfigAddOn1Tb": ".types",
    "ProductConfigAddOn1TbId": ".types",
    "ProductConfigAddOn200Gb": ".types",
    "ProductConfigAddOn200GbId": ".types",
    "ProductConfigAddOn500Gb": ".types",
    "ProductConfigAddOn500GbId": ".types",
    "ProductConfigChatAgent": ".types",
    "ProductConfigChatAgentId": ".types",
    "ProductConfigChatintegrationProfessional": ".types",
    "ProductConfigChatintegrationProfessionalId": ".types",
    "ProductConfigChatintegrationStarter": ".types",
    "ProductConfigChatintegrationStarterId": ".types",
    "ProductConfigDeveloper": ".types",
    "ProductConfigDeveloperId": ".types",
    "ProductConfigProjectroom": ".types",
    "ProductConfigProjectroomId": ".types",
    "UploadResponse": ".types",
    "VectorUpdateResponse": ".types",
    "__version__": ".version",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AsyncConcreteApi",
    "ConcreteApi",
    "ConcreteApiEnvironment",
    "HealthStatus",
    "Product",
    "ProductConfig",
    "ProductConfigAddOn1Tb",
    "ProductConfigAddOn1TbId",
    "ProductConfigAddOn200Gb",
    "ProductConfigAddOn200GbId",
    "ProductConfigAddOn500Gb",
    "ProductConfigAddOn500GbId",
    "ProductConfigChatAgent",
    "ProductConfigChatAgentId",
    "ProductConfigChatintegrationProfessional",
    "ProductConfigChatintegrationProfessionalId",
    "ProductConfigChatintegrationStarter",
    "ProductConfigChatintegrationStarterId",
    "ProductConfigDeveloper",
    "ProductConfigDeveloperId",
    "ProductConfigProjectroom",
    "ProductConfigProjectroomId",
    "UploadResponse",
    "VectorUpdateResponse",
    "__version__",
]
